pub struct NodeDataLayout {
pub inputs: HashSet<Uuid>,
pub outputs: HashSet<Uuid>,
pub queries: HashSet<Uuid>,
pub queryables: HashSet<Uuid>,
}Expand description
For internal use, this struct represents all the primitives belonging to a node. It is used to create the layout of the node.
Fields
inputs: HashSet<Uuid>outputs: HashSet<Uuid>queries: HashSet<Uuid>queryables: HashSet<Uuid>Auto Trait Implementations
impl Freeze for NodeDataLayout
impl RefUnwindSafe for NodeDataLayout
impl Send for NodeDataLayout
impl Sync for NodeDataLayout
impl Unpin for NodeDataLayout
impl UnsafeUnpin for NodeDataLayout
impl UnwindSafe for NodeDataLayout